@@ -86,7 +86,7 @@
 #define KARCHIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KARCHIVE_NO_DEPRECATED
-#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
 #endif
 #ifdef KARCHIVE_NO_DEPRECATED_WARNINGS
 #  define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KARCHIVE_DEPRECATED_WARNINGS_SINCE KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x55700
 #  endif
 #endif
 
@@ -115,6 +115,12 @@
 #else
 #  define KARCHIVE_DEPRECATED_VERSION_5_0(text)
 #endif
+
+#if KARCHIVE_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define KARCHIVE_DEPRECATED_VERSION_5_85(text) KARCHIVE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KARCHIVE_DEPRECATED_VERSION_5_85(text)
+#endif
 #define KARCHIVE_DEPRECATED_VERSION_5(minor, text)      KARCHIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KARCHIVE_DEPRECATED_VERSION(major, minor, text) KARCHIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KARCHIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KARCHIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -180,7 +186,7 @@
 #define KARCHIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KARCHIVE_NO_DEPRECATED
-#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
 #endif
 #ifdef KARCHIVE_NO_DEPRECATED_WARNINGS
 #  define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +196,7 @@
 #  ifdef KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KARCHIVE_DEPRECATED_WARNINGS_SINCE KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x55700
 #  endif
 #endif
 
@@ -209,6 +215,12 @@
 #else
 #  define KARCHIVE_DEPRECATED_VERSION_5_0(text)
 #endif
+
+#if KARCHIVE_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define KARCHIVE_DEPRECATED_VERSION_5_85(text) KARCHIVE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KARCHIVE_DEPRECATED_VERSION_5_85(text)
+#endif
 #define KARCHIVE_DEPRECATED_VERSION_5(minor, text)      KARCHIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KARCHIVE_DEPRECATED_VERSION(major, minor, text) KARCHIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KARCHIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KARCHIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
